#! /usr/bin/env bash

alias @=abcli

alias @T=abcli_terraform

alias @act=abcli_perform_action
alias @action=abcli_perform_action
alias @perform_action=abcli_perform_action

alias @assert=abcli_assert

alias @badge=abcli_badge

alias @browse=abcli_browse

alias @cache=abcli_cache
alias @ref="abcli_cache read"
alias @tag=abcli_tag
alias @relation=abcli_relation

alias @clone=abcli_clone
alias @copy=abcli_copy
alias @cp=abcli_cp

alias @conda=abcli_conda

alias @create_video=abcli_create_video

alias @download=abcli_download

alias @env=abcli_env

alias @eval=abcli_eval

alias @git=abcli_git
alias @git++="abcli_git increment_version"

alias @gpu=abcli_gpu

alias @help=abcli_help

alias @host=abcli_host

alias @hr=abcli_hr

alias @init=abcli_init

alias @instance=abcli_instance

alias @latex=abcli_latex

alias @log=abcli_log

alias @list=abcli_list
alias @ls=abcli_list

alias @mac='if [ "$abcli_is_mac" == true ]; then'
alias @.='fi'

alias @metadata=abcli_metadata

alias @object=abcli_object

alias @open=abcli_open

alias @option=abcli_option
alias @option::int=abcli_option_int
alias @option::choice=abcli_option_choice
alias @option::subset=abcli_option_subset

alias @pause=abcli_pause

alias @pip=abcli_pip

alias @plugins=abcli_plugins

alias @pypi=abcli_pypi

alias @pylint=abcli_pylint
alias @pytest=abcli_pytest

alias @publish=abcli_publish

alias @seed=abcli_seed

alias @select=abcli_select

alias @sleep=abcli_sleep

alias @storage=abcli_storage

alias @test=abcli_test

alias @timestamp=abcli_string_timestamp
alias @@timestamp=abcli_string_timestamp_short

alias @upload=abcli_upload

alias @version="abcli version"

alias @watch=abcli_watch
