import os
from abcli import env
from abcli import file


def test_abcli_env():
    assert env.HOME
    assert env.abcli_path_git
    assert env.abcli_path_storage

    assert env.ABCLI_AWS_RDS_DB
    assert env.ABCLI_AWS_RDS_PORT
    assert env.ABCLI_AWS_RDS_USER
